diff --git a/core/modules/node/node.module b/core/modules/node/node.module
index 349aab5..79aef60 100644
--- a/core/modules/node/node.module
+++ b/core/modules/node/node.module
@@ -1336,7 +1336,7 @@ function template_preprocess_node(&$variables) {
 
   $uri = $node->uri();
   $variables['node_url']  = url($uri['path'], $uri['options']);
-  $variables['title']     = check_plain($node->title);
+  $variables['label']     = check_plain($node->label());
   $variables['page']      = $variables['view_mode'] == 'full' && node_is_page($node);
 
   // Flatten the node entity's member fields.
diff --git a/core/modules/taxonomy/taxonomy.module b/core/modules/taxonomy/taxonomy.module
index a772e02..333378a 100644
--- a/core/modules/taxonomy/taxonomy.module
+++ b/core/modules/taxonomy/taxonomy.module
@@ -631,7 +631,7 @@ function template_preprocess_taxonomy_term(&$variables) {
 
   $uri = $term->uri();
   $variables['term_url']  = url($uri['path'], $uri['options']);
-  $variables['term_name'] = check_plain($term->name);
+  $variables['term_label'] = check_plain($term->label());
   $variables['page']      = $variables['view_mode'] == 'full' && taxonomy_term_is_page($term);
 
   // Flatten the term object's member fields.

diff --git a/core/modules/node/node.tpl.php b/core/modules/node/node.tpl.php
index 4645beb..9f40d45 100644
--- a/core/modules/node/node.tpl.php
+++ b/core/modules/node/node.tpl.php
@@ -5,7 +5,7 @@
  * Default theme implementation to display a node.
  *
  * Available variables:
  * - $title: the (sanitized) title of the node.
  * - $content: An array of node items. Use render($content) to print them all,
  *   or print a subset such as render($content['field_example']). Use
  *   hide($content['field_example']) to temporarily suppress the printing of a
@@ -80,7 +80,7 @@
 
   <?php print render($title_prefix); ?>
   <?php if (!$page): ?>
-    <h2<?php print $title_attributes; ?>><a href="<?php print $node_url; ?>" rel="bookmark"><?php print $title; ?></a></h2>
+    <h2<?php print $title_attributes; ?>><a href="<?php print $node_url; ?>" rel="bookmark"><?php print $label; ?></a></h2>
   <?php endif; ?>
   <?php print render($title_suffix); ?>
 
@@ -5,7 +5,7 @@
  *
  * Available variables:
- * - $title: the (sanitized) title of the node.
+ * - $label: the (sanitized) title of the node.
  * - $content: An array of node items. Use render($content) to print them all,
  *   or print a subset such as render($content['field_example']). Use
diff --git a/core/modules/taxonomy/taxonomy-term.tpl.php b/core/modules/taxonomy/taxonomy-term.tpl.php
index 8fdaa94..2451bd6 100644
--- a/core/modules/taxonomy/taxonomy-term.tpl.php
+++ b/core/modules/taxonomy/taxonomy-term.tpl.php
@@ -12,7 +12,7 @@
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
  * - $term_url: Direct url of the current term.
  * - $term_name: Name of the current term.
  * - $attributes: An instance of Attributes class that can be manipulated as an
  *    array and printed as a string.
  *    It includes the 'class' information, which includes:
@@ -39,7 +39,7 @@
 <div id="taxonomy-term-<?php print $term->tid; ?>"<?php print $attributes; ?>>
 
   <?php if (!$page): ?>
-    <h2><a href="<?php print $term_url; ?>"><?php print $term_name; ?></a></h2>
+    <h2><a href="<?php print $term_url; ?>"><?php print $term_label; ?></a></h2>
   <?php endif; ?>
 
   <div class="content">
@@ -12,7 +12,7 @@
  *   given element.
  * - $term_url: Direct url of the current term.
- * - $term_name: Name of the current term.
+ * - $term_label: Name of the current term.
  * - $attributes: An instance of Attributes class that can be manipulated as an
  *    array and printed as a string.